#!/usr/bin/python

#       Sgourakis Lab
#   Author: Andrew C. McShan
#   Edited by: Santrupti Nerli
#   Date: June 20, 2018
#   Email: snerli@ucsc.edu
#

'''

A dictionary of supported beta2m sequences

'''
# import required libraries
from collections import defaultdict

beta2m_sequences = defaultdict(dict)
beta2m_sequences['humanbeta2m']='IQRTPKIQVYSRHPAENGKSNFLNCYVSGFHPSDIEVDLLKNGERIEKVEHSDLSFSKDWSFYLLYYTEFTPTEKDEYACRVNHVTLSQPKIVKWDRDM'
beta2m_sequences['mousebeta2m']='IQKTPQIQVYSRHPPENGKPNILNCYVTQFHPPHIEIQMLKNGKKIPKVEMSDMSFSKDWSFYILAHTEFTPTETDTYACRVKHASMAEPKTVYWDRDM'
beta2m_sequences['chickenbeta2m']='ADLTPKVQVYSRFPASAGTKNVLNCFAAGFHPPKISITLMKDGVPMEGAQYSDMSFNDDWTFQRLVHADFTPSSGSTYACKVEHETLKEPQVYKWDPEF'
beta2m_sequences['bovinebeta2m']='IQRPPKIQVYSRHPPEDGKPNYLNCYVYGFHPPQIEIDLLKNGEKIEKSEQSDLSFSKDWSFYLLSHAEFTPNSKDQYSCRVKHVTLEQPRIVKWDRDL'
beta2m_sequences['ratbeta2m']='IQKTPQIQVYSRHPPENGKPNFLNCYVSQFHPPQIEIELLKNGKKIPNIEMSDLSFSKDWSFYILAHTEFTPTETDVYACRVKHVTLKEPKTVTWDRDM'
beta2m_sequences['none']=''
